==> huaweicloudsdkcbr-3.1.67-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/batch_update_vault_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchUpdateVaultRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'vault': 'VaultBatchUpdate'
    }

    attribute_map = {
        'vault': 'vault'
    }

    def __init__(self, vault=None):
        """BatchUpdateVaultRequestBody

        The model defined in huaweicloud sdk

        :param vault: 
        :type vault: :class:`huaweicloudsdkcbr.v1.VaultBatchUpdate`
        """
        
        

        self._vault = None
        self.discriminator = None

        self.vault = vault

    @property
    def vault(self):
        """Gets the vault of this BatchUpdateVaultRequestBody.

        :return: The vault of this BatchUpdateVaultRequestBody.
        :rtype: :class:`huaweicloudsdkcbr.v1.VaultBatchUpdate`
        """
        return self._vault

    @vault.setter
    def vault(self, vault):
        """Sets the vault of this BatchUpdateVaultRequestBody.

        :param vault: The vault of this BatchUpdateVaultRequestBody.
        :type vault: :class:`huaweicloudsdkcbr.v1.VaultBatchUpdate`
        """
        self._vault = vault

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchUpdateVaultRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.1.154-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/batch_update_vault_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchUpdateVaultRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'vault': 'VaultBatchUpdate'
    }

    attribute_map = {
        'vault': 'vault'
    }

    def __init__(self, vault=None):
        r"""BatchUpdateVaultRequestBody

        The model defined in huaweicloud sdk

        :param vault: 
        :type vault: :class:`huaweicloudsdkcbr.v1.VaultBatchUpdate`
        """
        
        

        self._vault = None
        self.discriminator = None

        self.vault = vault

    @property
    def vault(self):
        r"""Gets the vault of this BatchUpdateVaultRequestBody.

        :return: The vault of this BatchUpdateVaultRequestBody.
        :rtype: :class:`huaweicloudsdkcbr.v1.VaultBatchUpdate`
        """
        return self._vault

    @vault.setter
    def vault(self, vault):
        r"""Sets the vault of this BatchUpdateVaultRequestBody.

        :param vault: The vault of this BatchUpdateVaultRequestBody.
        :type vault: :class:`huaweicloudsdkcbr.v1.VaultBatchUpdate`
        """
        self._vault = vault

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchUpdateVaultRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
